@@ -6,7 +6,12 @@ package Bio::Tradis::AddTagsToSeq;
 use Moose;
 use Bio::Seq;
 use Bio::Tradis::Parser::Bam;
+use File::Basename;
 
+no warnings qw(uninitialized);
+
+has 'verbose' => ( is => 'rw', isa => 'Bool', default => 0 );
+has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 has 'bamfile' => ( is => 'rw', isa => 'Str', required => 1 );
 has 'outfile' => (
     is       => 'rw',
@@ -16,10 +21,21 @@ has 'outfile' => (
         my ($self) = @_;
         my $o = $self->bamfile;
         $o =~ s/\.bam/\.tr\.bam/;
+        $o =~ s/\.cram/\.tr\.cram/;
         return $o;
     }
 );
 
+has '_file_extension' => ( is => 'rw', isa => 'Str', lazy => 1, builder => '_build__file_extension' );
+has 'extension_to_output_switch' => ( is => 'rw', isa => 'HashRef', default => sub{ {cram => '-C', bam => '-b'} } );
+
+sub _build__file_extension
+{
+  my ($self) = @_;
+  my($filename, $dirs, $suffix) = fileparse($self->bamfile,qr/[^.]*/);
+  return lc($suffix);
+}
+
 sub add_tags_to_seq {
     my ($self) = @_;
 
@@ -28,14 +44,14 @@ sub add_tags_to_seq {
     my $outfile   = $self->outfile;
 
     #open temp file in SAM format and output headers from current BAM to it
-    print STDERR "Reading BAM header\n";
-    system("samtools view -H $filename > tmp.sam");
+    print STDERR "Reading ".uc($self->_file_extension)." header\n" if($self->verbose);
+    system($self->samtools_exec." view -H $filename > tmp.sam");
     open( TMPFILE, '>>tmp.sam' );
 
     #open BAM file
-    print STDERR "Reading BAM file\n";
-    my $pars = Bio::Tradis::Parser::Bam->new( file => $filename );
-	my $read_info = $pars->read_info;
+    print STDERR "Reading ".uc($self->_file_extension)." file\n" if($self->verbose);
+    my $pars = Bio::Tradis::Parser::Bam->new( file => $filename, samtools_exec => $self->samtools_exec );
+    my $read_info = $pars->read_info;
 
     while ( $pars->next_read ) {
         my $read_info = $pars->read_info;
@@ -80,7 +96,7 @@ sub add_tags_to_seq {
 
         }
         else {
-			print STDERR "$line\n" if(!defined($tqtag));
+			#print STDERR "$line\n" if(!defined($tqtag));
             $seq_tagged  = $trtag . $seq_tagged;
             $qual_tagged = $tqtag . $qual_tagged;
         }
@@ -105,8 +121,10 @@ sub add_tags_to_seq {
     close TMPFILE;
 
     #convert tmp.sam to bam
-    print STDERR "Convert SAM to BAM\n";
-    system("samtools view -S -b -o $outfile tmp.sam");
+    print STDERR "Convert SAM to ".uc($self->_file_extension)."\n" if($self->verbose);
+    
+    
+    system($self->samtools_exec." view -h -S ".$self->_output_switch." -o $outfile tmp.sam");
 
     if ( $self->_number_of_lines_in_bam_file($outfile) !=
         $self->_number_of_lines_in_bam_file($filename) )
@@ -120,9 +138,22 @@ sub add_tags_to_seq {
     return 1;
 }
 
+sub _output_switch
+{
+  my ( $self ) = @_;
+  if(defined($self->extension_to_output_switch->{$self->_file_extension}))
+  {
+    return $self->extension_to_output_switch->{$self->_file_extension};
+  }
+  else
+  {
+    return '';
+  }
+}
+
 sub _number_of_lines_in_bam_file {
     my ( $self, $filename ) = @_;
-    open( my $fh, '-|', "samtools view $filename | wc -l" )
+    open( my $fh, '-|', $self->samtools_exec." view $filename | wc -l" )
       or die "Couldn't open file :" . $filename;
     my $number_of_lines_in_file = <$fh>;
     $number_of_lines_in_file =~ s!\W!!gi;
@@ -137,13 +168,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::AddTagsToSeq - Takes a BAM file and creates a new BAM with tr and tq tags added to the sequence and quality strings.
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
