@@ -1,15 +1,15 @@
-
-
 package Bio::Tradis::Analysis::InsertSite;
+# ABSTRACT: Take in a bam file and plot the start position of each read
+
+
 use Moose;
 use Bio::Tradis::Parser::Bam;
-use Bio::DB::Sam;
-use Data::Dumper;
+use Bio::Tradis::Parser::Cigar;
 
 has 'filename'             => ( is => 'rw', isa => 'Str', required => 1 );
 has 'output_base_filename' => ( is => 'rw', isa => 'Str', required => 1 );
 has 'mapping_score'        => ( is => 'ro', isa => 'Int', required => 1 );
-has '_input_file_handle' => ( is => 'rw', lazy_build => 1 );
+has 'samtools_exec'        => ( is => 'ro', isa => 'Str', default => 'samtools' );
 has '_output_file_handles' => ( is => 'rw', isa => 'HashRef', lazy_build => 1 );
 has '_sequence_names' => ( is => 'rw', isa => 'ArrayRef', lazy_build => 1 );
 has '_sequence_base_counters' =>
@@ -27,7 +27,7 @@ has '_frequency_of_read_start' => (
 sub _build__sequence_information {
     my ($self) = @_;
     my %all_sequences_info =
-      Bio::Tradis::Parser::Bam->new( file => $self->filename )->seq_info;
+      Bio::Tradis::Parser::Bam->new( file => $self->filename, samtools_exec => $self->samtools_exec )->seq_info;
     return \%all_sequences_info;
 }
 
@@ -48,12 +48,15 @@ sub _build__sequence_base_counters {
 
 sub _build__output_file_handles {
     my ($self) = @_;
+    my $out = $self->output_base_filename;
+    chomp $out;
+    
     my %output_file_handles;
     for my $sequence_name ( @{ $self->_sequence_names } ) {
-        open( $output_file_handles{$sequence_name}, '|-',
-                " gzip >"
-              . $self->output_base_filename
-              . ".$sequence_name.insert_site_plot.gz" )
+        my $file_sequence_name = $sequence_name;
+        $file_sequence_name =~ s/[^\w\d\.]/_/g;
+        my $cmd = "gzip > $out.$file_sequence_name.insert_site_plot.gz";
+        open( $output_file_handles{$sequence_name}, '|-', $cmd )
           || Bio::Tradis::Analysis::Exceptions::FailedToCreateOutputFileHandle
           ->throw( error =>
 "Couldnt create output file handle for saving insertsite plot results for "
@@ -66,11 +69,6 @@ sub _build__output_file_handles {
     return \%output_file_handles;
 }
 
-sub _build__input_file_handle {
-    my ($self) = @_;
-    return Bio::DB::Bam->open( $self->filename );
-}
-
 sub _number_of_forward_reads {
     my ( $self, $sequence_name, $read_coord ) = @_;
     return $self->_number_of_reads( $sequence_name, $read_coord, 1 );
@@ -134,32 +132,66 @@ sub _close_output_file_handles {
 }
 
 sub _build__frequency_of_read_start {
-    my ($self) = @_;
-    my %frequency_of_read_start;
-    my $header       = $self->_input_file_handle->header;
-    my $target_names = $header->target_name;
-    while ( my $align = $self->_input_file_handle->read1 ) {
-        next if ( $align->unmapped );
+	my ($self) = @_;
+	my %frequency_of_read_start;
+	my $samtools_command = join(' ', ($self->samtools_exec, 'view', '-F', 4, '-q', $self->mapping_score, $self->filename));
 
-        # check quality score
-        my $quality = $align->qual;
-        if ( $quality >= $self->mapping_score ) {
-            my $seqid = $target_names->[ $align->tid ];
-            if ( $align->strand == 1 ) {
-                $frequency_of_read_start{$seqid}{ $align->start }
-                  { $align->strand }++;
-            }
-            else {
-                $frequency_of_read_start{$seqid}{ $align->end }
-                  { $align->strand }++;
-            }
+    open(my $samtools_view_fh,"-|" ,$samtools_command);
+	while(<$samtools_view_fh>)
+	{
+		my $sam_line = $_;
 
+		my @read_details = split("\t", $sam_line);
+		my $seqid = $read_details[2];
+		my $cigar_parser = Bio::Tradis::Parser::Cigar->new(cigar => $read_details[5], coordinate => $read_details[3]);
+		my $strand = 1;
+		$strand = -1 if(($read_details[1] &  0x10) == 0x10);
+		
+        if ( $strand == 1 ) {
+            $frequency_of_read_start{$seqid}{ $cigar_parser->start }
+              { $strand }++;
         }
-    }
-
-    return \%frequency_of_read_start;
+        else {
+            $frequency_of_read_start{$seqid}{ $cigar_parser->end }
+              { $strand }++;
+        }
+	}
+	return \%frequency_of_read_start;
 }
 
+#use Bio::DB::Sam;
+#has '_input_file_handle' => ( is => 'rw', lazy_build => 1 );
+#sub _build__input_file_handle {
+#    my ($self) = @_;
+#    return Bio::DB::Bam->open( $self->filename );
+#}
+#sub _build__frequency_of_read_start {
+#    my ($self) = @_;
+#    my %frequency_of_read_start;
+#    my $header       = $self->_input_file_handle->header;
+#    my $target_names = $header->target_name;
+#    while ( my $align = $self->_input_file_handle->read1 ) {
+#        next if ( $align->unmapped );
+#
+#        # check quality score
+#        my $quality = $align->qual;
+#        if ( $quality >= $self->mapping_score ) {
+#            my $seqid = $target_names->[ $align->tid ];
+#            if ( $align->strand == 1 ) {
+#                $frequency_of_read_start{$seqid}{ $align->start }
+#                  { $align->strand }++;
+#            }
+#            else {
+#                $frequency_of_read_start{$seqid}{ $align->end }
+#                  { $align->strand }++;
+#            }
+#
+#        }
+#    }
+#
+#    return \%frequency_of_read_start;
+#}
+
 sub create_plots {
     my ($self) = @_;
     my %read_starts = %{ $self->_frequency_of_read_start };
@@ -193,13 +225,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-Bio::Tradis::Analysis::InsertSite
+Bio::Tradis::Analysis::InsertSite - Take in a bam file and plot the start position of each read
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
