@@ -1,5 +1,5 @@
 package Bio::Tradis::CombinePlots;
-$Bio::Tradis::CombinePlots::VERSION = '1.4.3';
+
 # ABSTRACT: Combine multiple plotfiles and generate updated statistics for the combined files
 
 
@@ -309,7 +309,7 @@ Bio::Tradis::CombinePlots - Combine multiple plotfiles and generate updated stat
 
 =head1 VERSION
 
-version 1.4.3
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -324,12 +324,11 @@ For example, an input file named plots_to_combine.txt:
     tradis3 plot3.1.gz  plot3.2.gz plot3.3.gz   plot3.4.gz
 
 will produce 
-
 =over
 
-1. a directory named combined with 3 files - tradis1.insertion_site_plot.gz,
+=item 1. a directory named combined with 3 files - tradis1.insertion_site_plot.gz,
 tradis2.insertion_site_plot.gz, tradis3.insertion_site_plot.gz
-2. a stats file named plots_to_combine.stats
+=item 2. a stats file named plots_to_combine.stats
 
 =back
 
@@ -342,7 +341,7 @@ tradis2.insertion_site_plot.gz, tradis3.insertion_site_plot.gz
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
