@@ -12,22 +12,25 @@ has 'args'        => ( is => 'ro', isa => 'ArrayRef', required => 1 );
 has 'script_name' => ( is => 'ro', isa => 'Str',      required => 1 );
 has 'bamfile'        => ( is => 'rw', isa => 'Str', required => 0 );
 has 'help'        => ( is => 'rw', isa => 'Bool', required => 0 );
+has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 
 sub BUILD {
     my ($self) = @_;
     
     my (
-        $bamfile,	$help
+        $bamfile,	$help, $samtools_exec
     );
 
     GetOptionsFromArray(
         $self->args,
         'b|bamfile=s'                     => \$bamfile,
-		'h|help'                           => \$help
+		'h|help'                           => \$help,
+		'samtools_exec=s'   => \$samtools_exec,
     );
 	
     $self->bamfile(abs_path($bamfile))                   if ( defined($bamfile) );
 	$self->help($help)                                   if ( defined($help) );
+	    $self->samtools_exec($samtools_exec) if ( defined($samtools_exec) );
 
 	# print usage text if required parameters are not present
 	($bamfile) or die $self->usage_text;
@@ -37,11 +40,10 @@ sub run {
 	my ($self) = @_;
 	
 	if ( defined( $self->help ) ) {
-    #if ( scalar( @{ $self->args } ) == 0 ) {
           $self->usage_text;
     }
 	
-	my $tagcheck = Bio::Tradis::DetectTags->new(bamfile => $self->bamfile);
+	my $tagcheck = Bio::Tradis::DetectTags->new(bamfile => $self->bamfile, samtools_exec => $self->samtools_exec );
 	print $tagcheck->tags_present . "\n";
 }
 
@@ -66,13 +68,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::CommandLine::CheckTags - Check for presence of tr tag in BAM file
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
