@@ -1,5 +1,5 @@
 package Bio::Tradis::CommandLine::PlotCombine;
-$Bio::Tradis::CommandLine::PlotCombine::VERSION = '1.4.5';
+
 # ABSTRACT: Combine multiple plotfiles and generate updated statistics for the combined files
 
 
@@ -88,7 +88,7 @@ Bio::Tradis::CommandLine::PlotCombine - Combine multiple plotfiles and generate
 
 =head1 VERSION
 
-version 1.4.5
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -98,24 +98,22 @@ plotfile and as an identifier in the stats file, so ensure these are unique.
 
 For example, an input file named plots_to_combine.txt:
 
-   tradis1	plot1.1.gz	plot1.2.gz plot1.3.gz
-   tradis2 plot2.1.gz	plot2.2.gz
-   tradis3	plot3.1.gz	plot3.2.gz plot3.3.gz	plot3.4.gz
+tradis1	plot1.1.gz	plot1.2.gz plot1.3.gz
+tradis2 plot2.1.gz	plot2.2.gz
+tradis3	plot3.1.gz	plot3.2.gz plot3.3.gz	plot3.4.gz
 
 will produce:
-
 =over
 
 =item 1. a directory named combined with 3 files - tradis1.insertion_site_plot.gz,
 tradis2.insertion_site_plot.gz, tradis3.insertion_site_plot.gz
-
 =item 2. a stats file named plots_to_combine.stats
 
 =back
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
