@@ -17,25 +17,37 @@ has 'refname' =>
   ( is => 'rw', isa => 'Str', required => 0, default => 'ref.index' );
 has 'outfile' =>
   ( is => 'rw', isa => 'Str', required => 0, default => 'mapped.sam' );
+has 'smalt_k' => ( is => 'rw', isa => 'Maybe[Int]', required => 0 );
+has 'smalt_s' => ( is => 'rw', isa => 'Maybe[Int]', required => 0 );
+has 'smalt_y' => ( is => 'rw', isa => 'Maybe[Num]', required => 0, default => 0.96 );
+has 'smalt_r' => ( is => 'rw', isa => 'Maybe[Int]', required => 0, default => -1 );
 
 sub BUILD {
     my ($self) = @_;
 
-    my ( $fastqfile, $ref, $refname, $outfile, $help );
+    my ( $fastqfile, $ref, $refname, $outfile, $smalt_k, $smalt_s, $smalt_y, $smalt_r, $help );
 
     GetOptionsFromArray(
         $self->args,
-        'f|fastqfile=s' => \$fastqfile,
-        'r|reference=s' => \$ref,
-        'rn|refname=s'  => \$refname,
-        'o|outfile=s'   => \$outfile,
-        'h|help'        => \$help
+        'f|fastqfile=s'   => \$fastqfile,
+        'r|reference=s'   => \$ref,
+        'rn|refname=s'    => \$refname,
+        'o|outfile=s'     => \$outfile,
+	'sk|smalt_k=i'    => \$smalt_k,
+	'ss|smalt_s=i'    => \$smalt_s,
+	'sy|smalt_y=f'    => \$smalt_y,
+	'sr|smalt_r=i'    => \$smalt_r,
+        'h|help'          => \$help
     );
 
     $self->fastqfile( abs_path($fastqfile) ) if ( defined($fastqfile) );
     $self->reference( abs_path($ref) )       if ( defined($ref) );
     $self->refname($refname)                 if ( defined($refname) );
     $self->outfile( abs_path($outfile) )     if ( defined($outfile) );
+    $self->smalt_k( $smalt_k )               if ( defined($smalt_k) );
+    $self->smalt_s( $smalt_s )               if ( defined($smalt_s) );
+    $self->smalt_y( $smalt_y )               if ( defined($smalt_y) );
+    $self->smalt_r( $smalt_r )               if ( defined($smalt_r) );
     $self->help($help)                       if ( defined($help) );
 
 	# print usage text if required parameters are not present
@@ -54,7 +66,11 @@ sub run {
         fastqfile => $self->fastqfile,
         reference => $self->reference,
         refname   => $self->refname,
-        outfile   => $self->outfile
+        outfile   => $self->outfile,
+	smalt_k   => $self->smalt_k,
+	smalt_s   => $self->smalt_s,
+	smalt_y   => $self->smalt_y,
+	smalt_r   => $self->smalt_r
     );
     $mapping->index_ref;
     $mapping->do_mapping;
@@ -64,7 +80,8 @@ sub usage_text {
       print <<USAGE;
 Indexes the reference genome and maps the given fastq file.
 -k and -s options for indexing are calculated for the length of
-the read as follows
+the read as follows unless otherwise specified ( --smalt_k & 
+--smalt_s options )
 Read length    | k  |  s
 ---------------+----+-----
 <70            | 13 |  4
@@ -74,10 +91,13 @@ Read length    | k  |  s
 Usage: run_mapping -f file.fastq -r ref.fa [options]
 
 Options:
--f  : fastq file to map
--r	: reference in fasta format
--rn : reference index name (optional. default: ref.index)
--o  : mapped SAM output name (optional. default: mapped.sam)
+-f        : fastq file to map
+-r        : reference in fasta format
+-rn       : reference index name (optional. default: ref.index)
+-o        : mapped SAM output name (optional. default: mapped.sam)
+--smalt_k : custom k-mer value for SMALT mapping
+--smalt_s : custom step size for SMALT mapping
+--smalt_r : custom r value for SMALT mapping
 
 USAGE
       exit;
@@ -91,13 +111,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::CommandLine::RunMapping - Perform mapping
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
