@@ -23,22 +23,28 @@ has 'outfile'     => (
     }
 );
 has 'help' => ( is => 'rw', isa => 'Bool', required => 0 );
+has 'verbose'       => ( is => 'rw', isa => 'Bool', default => 0 );
+has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 
 sub BUILD {
     my ($self) = @_;
 
-    my ( $bamfile, $help, $outfile );
+    my ( $bamfile, $help, $outfile, $verbose, $samtools_exec );
 
     GetOptionsFromArray(
         $self->args,
         'b|bamfile=s' => \$bamfile,
         'o|outfile=s' => \$outfile,
-        'h|help'      => \$help
+        'h|help'      => \$help,
+        'v|verbose'         => \$verbose,
+        'samtools_exec=s'   => \$samtools_exec,
     );
 
     $self->bamfile( abs_path($bamfile) ) if ( defined($bamfile) );
     $self->outfile( abs_path($outfile) ) if ( defined($outfile) );
     $self->help($help)                   if ( defined($help) );
+    $self->verbose($verbose)             if ( defined($verbose) );
+    $self->samtools_exec($samtools_exec) if ( defined($samtools_exec) );
 
 	# print usage text if required parameters are not present
 	($bamfile) or die $self->usage_text;
@@ -48,16 +54,20 @@ sub run {
     my ($self) = @_;
 
     if ( defined( $self->help ) ) {
-    #if ( scalar( @{ $self->args } ) == 0 ) {
         $self->usage_text;
     }
 
     my $is_tradis =
-      Bio::Tradis::DetectTags->new( bamfile => $self->bamfile )->tags_present;
+      Bio::Tradis::DetectTags->new( 
+        bamfile       => $self->bamfile, 
+        samtools_exec => $self->samtools_exec 
+      )->tags_present;
     if ( defined($is_tradis) && $is_tradis == 1 ) {
         my $add_tag_obj = Bio::Tradis::AddTagsToSeq->new(
-            bamfile => $self->bamfile,
-            outfile => $self->outfile
+            bamfile       => $self->bamfile,
+            outfile       => $self->outfile,
+            verbose       => $self->verbose,
+            samtools_exec => $self->samtools_exec
         );
         $add_tag_obj->add_tags_to_seq;
     }
@@ -73,7 +83,7 @@ Usage: bam_to_tradis_bam -b file.bam [options]
 Options:
 -b  : bam file
 -o  : output BAM name (optional. default: <file>.tr.bam)
-
+-v  : verbose debugging output
 USAGE
     exit;
 }
@@ -86,13 +96,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::CommandLine::TradisBam - Adds tags to sequences if tags are present
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
