@@ -4,18 +4,26 @@ package Bio::Tradis::DetectTags;
 
 
 use Moose;
-use Bio::DB::Sam;
+use Bio::Tradis::Parser::Bam
 
 has 'bamfile' => ( is => 'ro', isa => 'Str', required => 1 );
+has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 
 sub tags_present {
     my ($self) = @_;
-    my $bam    = Bio::DB::Bam->open( $self->bamfile );
-    my $header = $bam->header;
-    my $a      = $bam->read1;
-    my $tr     = $a->get_tag_values('tr');
-    if   ( defined($tr) ) { return 1; }
-    else                  { return 0; }
+    my $pars = Bio::Tradis::Parser::Bam->new( file => $self->bamfile, samtools_exec => $self->samtools_exec );
+    my $read_info = $pars->read_info;
+    $pars->next_read;
+    $read_info = $pars->read_info;
+    if(defined(${$read_info}{tr}))
+    {
+      return 1;
+    }
+    else
+    { 
+      return 0;
+    }
+    
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -26,13 +34,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::DetectTags - Detect tr tags in BAM file
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
