@@ -1,11 +1,10 @@
 package Bio::Tradis::Exception;
 # ABSTRACT: Exceptions for input data 
-$Bio::Tradis::Exception::VERSION = '1.4.3';
+
 
 
 use Exception::Class (
-    Bio::Tradis::Exception::RefNotFound    => { description => 'Cannot find the reference file' },
-    Bio::Tradis::Exception::TagFilterError => { description => 'Problem filtering the Fastq by tag' }
+    Bio::Tradis::Exception::RefNotFound => { description => 'Cannot find the reference file' }
 );  
 
 1;
@@ -22,7 +21,7 @@ Bio::Tradis::Exception - Exceptions for input data
 
 =head1 VERSION
 
-version 1.4.3
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -30,7 +29,7 @@ Exceptions for input data
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
