@@ -12,6 +12,10 @@ has 'refname' =>
   ( is => 'rw', isa => 'Str', required => 0, default => 'ref.index' );
 has 'outfile' =>
   ( is => 'rw', isa => 'Str', required => 0, default => 'mapped.sam' );
+has 'smalt_k' => ( is => 'rw', isa => 'Maybe[Int]', required => 0 );
+has 'smalt_s' => ( is => 'rw', isa => 'Maybe[Int]', required => 0 );
+has 'smalt_y' => ( is => 'rw', isa => 'Maybe[Num]', required => 0, default => 0.96 );
+has 'smalt_r' => ( is => 'rw', isa => 'Maybe[Int]', required => 0, default => -1 );
 
 sub index_ref {
     my ($self)  = @_;
@@ -22,21 +26,38 @@ sub index_ref {
     my $pars = Bio::Tradis::Parser::Fastq->new( file => $self->fastqfile );
     $pars->next_read;
     my @read = $pars->read_info;
-    my ( $k, $s );
-    ( $k, $s ) = ( 13, 4 );
-    my $seq = $read[1];
-    if ( length($seq) < 70 ) {
-        ( $k, $s ) = ( 13, 4 );
-    }
-    elsif ( length($seq) > 70 && length($seq) < 100 ) {
-        ( $k, $s ) = ( 13, 6 );
-    }
-    else {
-        ( $k, $s ) = ( 20, 13 );
-    }
+	my $read_len = length($read[1]);
+    my ( $k, $s ) = $self->_calculate_index_parameters($read_len);
 
-    system("smalt index -k $k -s $s $refname $ref");
-    return 1;
+    my $cmd = "smalt index -k $k -s $s $refname $ref > /dev/null 2>&1";
+    system($cmd);
+    return $cmd;
+}
+
+sub _calculate_index_parameters {
+	my ($self, $read_len)  = @_;
+	my ( $k, $s );
+	
+	if( defined $self->smalt_k ){ $k = $self->smalt_k; }
+	else{ $k = $self->_smalt_k_default($read_len); }
+	
+	if( defined $self->smalt_s ){ $s = $self->smalt_s; }
+	else{ $s = $self->_smalt_s_default($read_len); }
+	
+	return ( $k, $s );
+}
+
+sub _smalt_k_default {
+	my ($self, $read_len)  = @_;
+	if($read_len < 100){ return 13; }
+	else{ return 20; }
+}
+
+sub _smalt_s_default {
+	my ( $self, $read_len )  = @_;
+	if( $read_len < 70 ){ return 4; }
+	elsif( $read_len > 100 ){ return 13; }
+	else{ return 6; }
 }
 
 sub do_mapping {
@@ -44,10 +65,15 @@ sub do_mapping {
     my $fqfile  = $self->fastqfile;
     my $refname = $self->refname;
     my $outfile = $self->outfile;
+    my $y = $self->smalt_y;
+    my $r = $self->smalt_r;
 
-    system("smalt map -x -r -1 -y 0.96 $refname $fqfile 1> $outfile  2> smalt.stderr");
-	unlink('smalt.stderr');
-	return 1;
+    my $smalt = "smalt map -x -r $r -y $y $refname $fqfile 1> $outfile  2> smalt.stderr";
+
+    system($smalt);
+    unlink('smalt.stderr');
+    
+    return $smalt;
 }
 
 __PACKAGE__->meta->make_immutable;
@@ -58,13 +84,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::Map - Perform mapping
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
