@@ -5,6 +5,7 @@ package Bio::Tradis::Parser::Bam;
 
 use Moose;
 
+has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
 has 'file' => ( is => 'rw', isa => 'Str', required => 1 );
 has '_bam_handle' => (
     is       => 'ro',
@@ -26,7 +27,7 @@ sub _build__bam_handle {
     my ($self) = @_;
     my $bamfile = $self->file;
 
-    open( my $bamh, "-|", "samtools view $bamfile" )
+    open( my $bamh, "-|", $self->samtools_exec." view $bamfile" )
       or die "Cannot open $bamfile";
     return $bamh;
 }
@@ -73,7 +74,7 @@ sub seq_info {
     my $bamfile = $self->file;
 
     my ( %all_seq_info, $seq_name, %this_seq_info );
-    open( SINFO, "-|", "samtools view -H $bamfile | grep ^\@SQ | cut -f 2-" );
+    open( SINFO, "-|", $self->samtools_exec." view -H $bamfile | grep ^\@SQ | cut -f 2-" );
     while ( my $line = <SINFO> ) {
         chomp($line);
         my @fields = split( '\t', $line );
@@ -148,13 +149,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::Parser::Bam - Very basic BAM parser. Limited functionality.
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
