@@ -1,5 +1,5 @@
 package Bio::Tradis::Parser::Cigar;
-$Bio::Tradis::Parser::Cigar::VERSION = '1.4.5';
+
 # ABSTRACT: Take in a cigar string and output start and end relative to the reference sequence
 
 
@@ -71,7 +71,7 @@ Bio::Tradis::Parser::Cigar - Take in a cigar string and output start and end rel
 
 =head1 VERSION
 
-version 1.4.5
+version 1.2
 
 =head1 SYNOPSIS
 
@@ -85,7 +85,7 @@ Take in a cigar string and output start and end relative to the reference sequen
 
 =head1 AUTHOR
 
-Carla Cummins <path-help@sanger.ac.uk>
+Carla Cummins <cc21@sanger.ac.uk>
 
 =head1 COPYRIGHT AND LICENSE
 
