@@ -9,7 +9,9 @@ use Bio::Tradis::FilterTags;
 use Bio::Tradis::RemoveTags;
 use Bio::Tradis::Map;
 use Bio::Tradis::TradisPlot;
+use Bio::Tradis::Exception;
 
+has 'verbose' => ( is => 'rw', isa => 'Bool', default => 0 );
 has 'fastqfile' => ( is => 'rw', isa => 'Str', required => 1 );
 has '_unzipped_fastq' =>
   ( is => 'rw', isa => 'Str', lazy => 1, builder => '_build__unzipped_fastq' );
@@ -32,6 +34,12 @@ has 'outfile' => (
         return $o;
     }
 );
+has 'smalt_k' => ( is => 'rw', isa => 'Maybe[Int]',   required => 0 );
+has 'smalt_s' => ( is => 'rw', isa => 'Maybe[Int]',   required => 0 );
+has 'smalt_y' => ( is => 'rw', isa => 'Maybe[Num]', required => 0, default => 0.96 );
+has 'smalt_r' => ( is => 'rw', isa => 'Maybe[Int]', required => 0, default => -1);
+has 'samtools_exec' => ( is => 'rw', isa => 'Str', default => 'samtools' );
+
 has '_destination' => (
     is       => 'rw',
     isa      => 'Str',
@@ -127,47 +135,50 @@ sub run_tradis {
     my ($self)                = @_;
     my $destination_directory = $self->_destination;
     my $fq                    = $self->fastqfile;
+    
+    my $ref                   = $self->reference;
+    Bio::Tradis::Exception::RefNotFound->throw( error => "$ref not found\n" ) unless( -e $ref );
 
-    print STDERR "::::::::::::::::::\n$fq\n::::::::::::::::::\n\n";
+    print STDERR "::::::::::::::::::\n$fq\n::::::::::::::::::\n\n" if($self->verbose);
 
     # Step 1: Filter tags that match user input tag
-    print STDERR "..........Step 1: Filter tags that match user input tag\n";
+    print STDERR "..........Step 1: Filter tags that match user input tag\n" if($self->verbose);
     $self->_filter;
 
     # Step 2: Remove the tag from the sequence and quality strings
     print STDERR
-"..........Step 2: Remove the tag from the sequence and quality strings\n";
+"..........Step 2: Remove the tag from the sequence and quality strings\n" if($self->verbose);
     $self->_remove;
 
     # Step 3: Map file to reference
-    print STDERR "..........Step 3: Map file to reference\n";
+    print STDERR "..........Step 3: Map file to reference\n" if($self->verbose);
     $self->_map;
 
     # Step 4: Convert output from SAM to BAM, sort and index
     print STDERR
-      "..........Step 3.5: Convert output from SAM to BAM and sort\n";
+      "..........Step 3.5: Convert output from SAM to BAM and sort\n" if($self->verbose);
     $self->_sam2bam;
     $self->_sort_bam;
+    $self->_bamcheck;
 
     # Step 5: Generate plot
-    print STDERR "..........Step 4: Generate plot\n";
+    print STDERR "..........Step 4: Generate plot\n" if($self->verbose);
     $self->_make_plot;
 
     # Step 6: Generate statistics
-    print STDERR "..........Step 5: Generate statistics\n";
+    print STDERR "..........Step 5: Generate statistics\n" if($self->verbose);
     $self->_stats;
 
     # Step 7: Move files to current directory
-    print STDERR "..........Step 6: Move files to current directory\n";
+    print STDERR "..........Step 6: Move files to current directory\n" if($self->verbose);
     my $outfile = $self->outfile;
     system("mv $destination_directory/$outfile* \.");
     system("mv $destination_directory/mapped.sort.bam \./$outfile.mapped.bam");
-    system(
-"mv $destination_directory/mapped.sort.bam.bai \./$outfile.mapped.bam.bai"
-    );
+    system("mv $destination_directory/mapped.sort.bam.bai \./$outfile.mapped.bam.bai");
+    system("mv $destination_directory/mapped.bamcheck \./$outfile.mapped.bamcheck");
 
     # Clean up
-    print STDERR "..........Clean up\n";
+    print STDERR "..........Clean up\n" if($self->verbose);
 
     unlink("$destination_directory/filter.fastq");
     unlink("$destination_directory/tags_removed.fastq");
@@ -176,7 +187,7 @@ sub run_tradis {
     unlink("$destination_directory/ref.index.smi");
     unlink("$destination_directory/mapped.bam");
     unlink("$destination_directory/tmp.plot");
-	unlink($self->_unzipped_fastq) if ($self->_is_gz);
+    unlink( $self->_unzipped_fastq ) if ( $self->_is_gz );
 
     File::Temp::cleanup();
 
@@ -222,7 +233,11 @@ sub _map {
         fastqfile => "$destination_directory/tags_removed.fastq",
         reference => "$ref",
         refname   => "$destination_directory/ref.index",
-        outfile   => "$destination_directory/mapped.sam"
+        outfile   => "$destination_directory/mapped.sam",
+        smalt_k   => $self->smalt_k,
+        smalt_s   => $self->smalt_s,
+        smalt_y   => $self->smalt_y,
+	smalt_r   => $self->smalt_r
     );
     $mapping->index_ref;
     $mapping->do_mapping;
@@ -233,7 +248,7 @@ sub _sam2bam {
     my $destination_directory = $self->_destination;
 
     system(
-"samtools view -b -o $destination_directory/mapped.bam -S $destination_directory/mapped.sam"
+$self->samtools_exec." view -b -o $destination_directory/mapped.bam -S $destination_directory/mapped.sam"
     );
     return 1;
 }
@@ -243,9 +258,19 @@ sub _sort_bam {
     my $destination_directory = $self->_destination;
 
     system(
-"samtools sort $destination_directory/mapped.bam $destination_directory/mapped.sort"
+$self->samtools_exec." sort $destination_directory/mapped.bam $destination_directory/mapped.sort"
+    );
+    system($self->samtools_exec." index $destination_directory/mapped.sort.bam");
+    return 1;
+}
+
+sub _bamcheck {
+    my ($self) = @_;
+    my $destination_directory = $self->_destination;
+
+    system(
+$self->samtools_exec." stats $destination_directory/mapped.sort.bam > $destination_directory/mapped.bamcheck"
     );
-    system("samtools index $destination_directory/mapped.sort.bam");
     return 1;
 }
 
@@ -255,7 +280,7 @@ sub _make_plot {
     my $ref                   = $self->reference;
     my $outfile               = $self->outfile;
     my $tr_d                  = $self->tagdirection;
-	
+
     my $plot = Bio::Tradis::TradisPlot->new(
         mappedfile    => "$destination_directory/mapped.sort.bam",
         mapping_score => $self->mapping_score,
@@ -264,9 +289,10 @@ sub _make_plot {
 
     # if tag direction is 5, reverse plot columns
     if ( $self->tagdirection eq '5' ) {
+        print STDERR "Tag direction = 5. Reversing plot..\n" if($self->verbose);
         $self->_reverse_plots;
     }
-	return 1;
+    return 1;
 }
 
 sub _reverse_plots {
@@ -275,8 +301,13 @@ sub _reverse_plots {
     my $outfile               = $self->outfile;
     my @seqnames              = keys %{ $self->_sequence_info };
 
-    foreach my $sn (@seqnames) {
-        my $plotname = $self->_plotname($sn);
+    my @current_plots =
+      glob("$destination_directory/$outfile.*.insert_site_plot.gz");
+
+    foreach my $plotname (@current_plots) {
+        print STDERR "Reversing $plotname\n" if($self->verbose);
+
+        #my $plotname = $self->_plotname($sn);
         system("gunzip -c $plotname > $destination_directory/tmp.plot");
         system(
 "awk '{ t = \$1; \$1 = \$2; \$2 = t; print; }' $destination_directory/tmp.plot > rv_plot"
@@ -323,19 +354,19 @@ sub _stats {
         system(
 "gunzip -c $destination_directory/$plotname > $destination_directory/tmp.plot"
         );
-        my $uis =
-`grep -v "^0" $destination_directory/tmp.plot | sort | uniq | wc | awk '{ print \$1 }'`;
+        my $uis = `grep -c -v "0 0" $destination_directory/tmp.plot`;
         chomp($uis);
         $total_uis += $uis;
         $stats .= "$uis,";
         my $seqlen = ${$seq_info}{$si};
         $total_seq_len += $seqlen;
-        my $uis_per_seqlen = $uis / $seqlen;
+        my $uis_per_seqlen = "NaN";
+        $uis_per_seqlen = $seqlen / $uis if ( $uis > 0 );
         chomp($uis_per_seqlen);
         $stats .= "$uis_per_seqlen,";
     }
     $stats .= "$total_uis,";
-    my $t_uis_p_l = $total_uis / $total_seq_len;
+    my $t_uis_p_l = $total_seq_len / $total_uis;
     $stats .= "$t_uis_p_l\n";
     print { $self->_stats_handle } $stats;
 }
@@ -354,16 +385,17 @@ sub _write_stats_header {
     print { $self->_stats_handle } join( ",", @fields ) . ",";
     foreach my $sn (@seqnames) {
         print { $self->_stats_handle } "Unique Insertion Sites : $sn,";
-        print { $self->_stats_handle } "UIS/Seq Len : $sn,";
+        print { $self->_stats_handle } "Seq Len/UIS : $sn,";
     }
     print { $self->_stats_handle } "Total Unique Insertion Sites,";
-    print { $self->_stats_handle } "Total UIS/Total Seq Len\n";
+    print { $self->_stats_handle } "Total Seq Len/Total UIS\n";
 }
 
 sub _plotname {
     my ( $self, $seq_name ) = @_;
     my $outfile = $self->outfile;
 
+    $seq_name =~ s/[^\w\d\.]/_/g;
     my $plotfile_name = "$outfile.$seq_name.insert_site_plot.gz";
     return $plotfile_name;
 }
@@ -392,13 +424,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Bio::Tradis::RunTradis - Perform all steps required for a tradis analysis
 
 =head1 VERSION
 
-version 1.132190
+version 1.2
 
 =head1 SYNOPSIS
 
